@@ -597,7 +597,7 @@ def prog_cxx_flag( flags ):
 # end
 
 #-------------------------------------------------------------------------------
-def openmp( flags=['-fopenmp', '-qopenmp', '-openmp', '-omp', ''] ):
+def openmp( flags=['-qopenmp', '-fopenmp', '-openmp', '-omp', ''] ):
     '''
     Tests for OpenMP support with one of the given flags.
     If a flag works, it is added to both CXXFLAGS and LDFLAGS.
@@ -723,8 +723,7 @@ def sycl_onemkl_library():
     root = environ['CMPLR_ROOT'] or environ['CMPROOT']
     inc = ''
     if (root):
-        inc = '-I' + root + '/linux/include ' \
-            + '-I' + root + '/linux/include/sycl '
+        inc = '-I' + root + '/linux/include '  # space at end for concat
     env = {'LIBS': libs,
            'CXXFLAGS': inc + define('HAVE_SYCL')
            + ' -fsycl -Wno-deprecated-declarations'}
@@ -784,6 +783,27 @@ def gpu_blas():
         print_warn( 'No GPU BLAS library found' )
 # end
 
+#-------------------------------------------------------------------------------
+def libatomic():
+    '''
+    Tests whether using `std::atomic` requires linking with `-latomic`
+    for 64-bit values, which is the case on some 32-bit systems.
+    If so, adds `-latomic` to LIBS.
+    '''
+    print_test( 'std::atomic links without -latomic' )
+    (rc, out, err) = compile_exe( 'config/std_atomic.cc' )
+    print_result( 'x', rc )
+    if (rc != 0):
+        print_test( 'std::atomic requires -latomic' )
+        env = {'LIBS': '-latomic'}
+        (rc, out, err) = compile_exe( 'config/std_atomic.cc', env )
+        print_result( 'x', rc )
+        if (rc == 0):
+            environ.merge( env )
+        else:
+            raise Error( 'cannot compile libatomic test' )
+# end
+
 #-------------------------------------------------------------------------------
 def get_package( name, directories, repo_url, tar_url, tar_filename ):
     '''
@@ -989,7 +1009,7 @@ def parse_args():
 
     # Parse name=value pairs.
     for arg in opts.options:
-        s = re.search( '^(\w+)=(.*)', arg )
+        s = re.search( r'^(\w+)=(.*)', arg )
         if (s):
             environ[ s.group(1) ] = s.group(2)
         else:
