@@ -57,6 +57,9 @@ def main():
    #config.prog_cxx_flag( '-Wconversion' )
    #config.prog_cxx_flag( '-Werror' )
 
+    print_header( 'Libraries' )
+    config.libatomic()
+
     config.openmp()
 
     config.lapack.blas()
@@ -73,8 +76,9 @@ def main():
 
     try:
         config.lapack.lapack()
-    except Error:
-        print_warn( 'BLAS++ needs LAPACK for testers.' )
+    except Error as ex:
+        print_warn( 'BLAS++ requires LAPACK for [cz]rot, [cz]syr, [cz]symv.' )
+        raise( ex )
 
     config.gpu_blas()
 
