@@ -58,6 +58,68 @@ cublasSideMode_t side2cublas(blas::Side side)
 //==============================================================================
 // Level 1 BLAS - Device Interfaces
 
+//------------------------------------------------------------------------------
+// asum
+//------------------------------------------------------------------------------
+void asum(
+    device_blas_int n,
+    float const* dx, device_blas_int incdx,
+    float* result,
+    blas::Queue& queue )
+{
+    blas_dev_call(
+        cublasSasum(
+            queue.handle(),
+            n,
+            dx, incdx,
+            result));
+}
+
+//------------------------------------------------------------------------------
+void asum(
+    device_blas_int n,
+    double const* dx, device_blas_int incdx,
+    double* result,
+    blas::Queue& queue )
+{
+    blas_dev_call(
+        cublasDasum(
+            queue.handle(),
+            n,
+            dx, incdx,
+            result));
+}
+
+//------------------------------------------------------------------------------
+void asum(
+    device_blas_int n,
+    std::complex<float> const* dx, device_blas_int incdx,
+    float* result,
+    blas::Queue& queue )
+{
+    blas_dev_call(
+        cublasScasum(
+            queue.handle(),
+            n,
+            (const cuComplex*) dx, incdx,
+            result));
+}
+
+//------------------------------------------------------------------------------
+void asum(
+    device_blas_int n,
+    std::complex<double> const* dx, device_blas_int incdx,
+    double* result,
+    blas::Queue& queue )
+{
+    blas_dev_call(
+        cublasDzasum(
+            queue.handle(),
+            n,
+            (const cuDoubleComplex*) dx, incdx,
+            result));
+}
+
 //------------------------------------------------------------------------------
 // axpy
 //------------------------------------------------------------------------------
@@ -228,6 +290,181 @@ void dotu(
             (cuDoubleComplex*) result));
 }
 
+//------------------------------------------------------------------------------
+// iamax
+//------------------------------------------------------------------------------
+void iamax(
+    int64_t n,
+    float const *dx, int64_t incdx,
+    int64_t* result,
+    blas::Queue& queue )
+{
+    #if CUBLAS_VER_MAJOR >= 12
+        blas_dev_call(
+            cublasIsamax_64(
+                queue.handle(),
+                n,
+                dx, incdx,
+                result));
+    #else
+        // clear memory
+        if (! is_devptr( result, queue )) {
+            *result = 0;
+        }
+        else {
+            blas_dev_call(
+                cudaMemsetAsync( result, 0, sizeof( *result ) ));
+        }
+        // convert arguments
+        device_blas_int n_    = to_device_blas_int( n );
+        device_blas_int incdx_ = to_device_blas_int( incdx );
+        device_blas_int* result_ = (device_blas_int*) result;
+        blas_dev_call(
+            cublasIsamax(
+                queue.handle(),
+                n_,
+                dx, incdx_,
+                result_ ));
+    #endif
+    // cublas returns 1-based index
+    if (! is_devptr( result, queue )) {
+        *result -= 1;
+    }
+    else {
+        shift_vec( 1, result, (int64_t) -1, queue );
+    }
+}
+
+//------------------------------------------------------------------------------
+void iamax(
+    int64_t n,
+    double const *dx, int64_t incdx,
+    int64_t* result,
+    blas::Queue& queue )
+{
+    #if CUBLAS_VER_MAJOR >= 12
+        blas_dev_call(
+            cublasIdamax_64(
+                queue.handle(),
+                n,
+                dx, incdx,
+                result));
+    #else
+        // clear memory
+        if (! is_devptr( result, queue )) {
+            *result = 0;
+        }
+        else {
+            blas_dev_call(
+                cudaMemsetAsync( result, 0, sizeof( *result ) ));
+        }
+        // convert arguments
+        device_blas_int n_    = to_device_blas_int( n );
+        device_blas_int incdx_ = to_device_blas_int( incdx );
+        device_blas_int* result_ = (device_blas_int*) result;
+
+        blas_dev_call(
+            cublasIdamax(
+                queue.handle(),
+                n_,
+                dx, incdx_,
+                result_));
+    #endif
+    // cublas returns 1-based index
+    if (! is_devptr( result, queue )) {
+        *result -= 1;
+    }
+    else {
+        shift_vec( 1, result, (int64_t) -1, queue );
+    }
+}
+
+//------------------------------------------------------------------------------
+void iamax(
+    int64_t n,
+    std::complex<float> const *dx, int64_t incdx,
+    int64_t* result,
+    blas::Queue& queue )
+{
+    #if CUBLAS_VER_MAJOR >= 12
+        blas_dev_call(
+            cublasIcamax_64(
+                queue.handle(),
+                n,
+                (const cuComplex*) dx, incdx,
+                result));
+    #else
+        // clear memory
+        if (! is_devptr( result, queue )) {
+            *result = 0;
+        }
+        else {
+            blas_dev_call(
+                cudaMemsetAsync( result, 0, sizeof( *result ) ));
+        }
+        // convert arguments
+        device_blas_int n_    = to_device_blas_int( n );
+        device_blas_int incdx_ = to_device_blas_int( incdx );
+        device_blas_int* result_ = (device_blas_int*) result;
+        blas_dev_call(
+            cublasIcamax(
+                queue.handle(),
+                n_,
+                (const cuComplex*) dx, incdx_,
+                result_));
+    #endif
+    // cublas returns 1-based index
+    if (! is_devptr( result, queue )) {
+        *result -= 1;
+    }
+    else {
+        shift_vec( 1, result, (int64_t) -1, queue );
+    }
+}
+
+//------------------------------------------------------------------------------
+void iamax(
+    int64_t n,
+    std::complex<double> const *dx, int64_t incdx,
+    int64_t* result,
+    blas::Queue& queue )
+{
+    #if CUBLAS_VER_MAJOR >= 12
+        blas_dev_call(
+            cublasIzamax_64(
+                queue.handle(),
+                n,
+                (const cuDoubleComplex*) dx, incdx,
+                result));
+    #else
+        // clear memory
+        if (! is_devptr( result, queue )) {
+            *result = 0;
+        }
+        else {
+            blas_dev_call(
+                cudaMemsetAsync( result, 0, sizeof( *result ) ));
+        }
+        // convert arguments
+        device_blas_int n_    = to_device_blas_int( n );
+        device_blas_int incdx_ = to_device_blas_int( incdx );
+        device_blas_int* result_ = (device_blas_int*) result;
+        blas_dev_call(
+            cublasIzamax(
+                queue.handle(),
+                n_,
+                (const cuDoubleComplex*) dx, incdx_,
+                result_));
+    #endif
+    // cublas returns 1-based index
+    if (! is_devptr( result, queue )) {
+        *result -= 1;
+    }
+    else {
+        shift_vec( 1, result, (int64_t) -1, queue );
+    }
+}
+
 // -----------------------------------------------------------------------------
 // nrm2
 //------------------------------------------------------------------------------
@@ -468,6 +705,262 @@ void copy(
             (cuDoubleComplex*) dy, incdy) );
 }
 
+//------------------------------------------------------------------------------
+// rot
+//------------------------------------------------------------------------------
+void rot(
+    device_blas_int n,
+    float* dx, device_blas_int incdx,
+    float* dy, device_blas_int incdy,
+    const float c,
+    const float s,
+    blas::Queue& queue )
+{
+    blas_dev_call(
+        cublasSrot(
+            queue.handle(),
+            n,
+            dx, incdx,
+            dy, incdy,
+            &c, &s));
+}
+
+//------------------------------------------------------------------------------
+void rot(
+    device_blas_int n,
+    double* dx, device_blas_int incdx,
+    double* dy, device_blas_int incdy,
+    const double c,
+    const double s,
+    blas::Queue& queue )
+{
+    blas_dev_call(
+        cublasDrot(
+            queue.handle(),
+            n,
+            dx, incdx,
+            dy, incdy,
+            &c, &s));
+}
+
+//------------------------------------------------------------------------------
+void rot(
+    device_blas_int n,
+    std::complex<float>* dx, device_blas_int incdx,
+    std::complex<float>* dy, device_blas_int incdy,
+    const float c,
+    const float s,
+    blas::Queue& queue )
+{
+    blas_dev_call(
+        cublasCsrot(
+            queue.handle(),
+            n,
+            (cuComplex*) dx, incdx,
+            (cuComplex*) dy, incdy,
+            &c, &s));
+}
+
+//------------------------------------------------------------------------------
+void rot(
+    device_blas_int n,
+    std::complex<double>* dx, device_blas_int incdx,
+    std::complex<double>* dy, device_blas_int incdy,
+    const double c,
+    const double s,
+    blas::Queue& queue )
+{
+    blas_dev_call(
+        cublasZdrot(
+            queue.handle(),
+            n,
+            (cuDoubleComplex*) dx, incdx,
+            (cuDoubleComplex*) dy, incdy,
+            &c, &s));
+}
+
+//------------------------------------------------------------------------------
+void rot(
+    device_blas_int n,
+    std::complex<float>* dx, device_blas_int incdx,
+    std::complex<float>* dy, device_blas_int incdy,
+    const float c,
+    const std::complex<float> s,
+    blas::Queue& queue )
+{
+    blas_dev_call(
+        cublasCrot(
+            queue.handle(),
+            n,
+            (cuComplex*) dx, incdx,
+            (cuComplex*) dy, incdy,
+            &c, (cuComplex*) &s));
+}
+
+//------------------------------------------------------------------------------
+void rot(
+    device_blas_int n,
+    std::complex<double>* dx, device_blas_int incdx,
+    std::complex<double>* dy, device_blas_int incdy,
+    const double c,
+    const std::complex<double> s,
+    blas::Queue& queue )
+{
+    blas_dev_call(
+        cublasZrot(
+            queue.handle(),
+            n,
+            (cuDoubleComplex*) dx, incdx,
+            (cuDoubleComplex*) dy, incdy,
+            &c, (cuDoubleComplex*) &s));
+}
+
+//------------------------------------------------------------------------------
+// rotg
+//------------------------------------------------------------------------------
+void rotg(
+    float* da,
+    float* db,
+    float* dc,
+    float* ds,
+    blas::Queue& queue )
+{
+    blas_dev_call(
+        cublasSrotg(
+            queue.handle(),
+            da,
+            db,
+            dc,
+            ds));
+}
+
+//------------------------------------------------------------------------------
+void rotg(
+    double* da,
+    double* db,
+    double* dc,
+    double* ds,
+    blas::Queue& queue )
+{
+    blas_dev_call(
+        cublasDrotg(
+            queue.handle(),
+            da,
+            db,
+            dc,
+            ds));
+}
+
+//------------------------------------------------------------------------------
+void rotg(
+    std::complex<float>* da,
+    std::complex<float>* db,
+    float* dc,
+    std::complex<float>* ds,
+    blas::Queue& queue )
+{
+    blas_dev_call(
+        cublasCrotg(
+            queue.handle(),
+            (cuComplex*) da,
+            (cuComplex*) db,
+            dc,
+            (cuComplex*) ds));
+}
+
+//------------------------------------------------------------------------------
+void rotg(
+    std::complex<double>* da,
+    std::complex<double>* db,
+    double* dc,
+    std::complex<double>* ds,
+    blas::Queue& queue )
+{
+    blas_dev_call(
+        cublasZrotg(
+            queue.handle(),
+            (cuDoubleComplex*) da,
+            (cuDoubleComplex*) db,
+            dc,
+            (cuDoubleComplex*) ds));
+}
+
+//------------------------------------------------------------------------------
+// rotm
+//------------------------------------------------------------------------------
+void rotm(
+    device_blas_int n,
+    float* dx, device_blas_int incdx,
+    float* dy, device_blas_int incdy,
+    const float* param,
+    blas::Queue& queue )
+{
+    blas_dev_call(
+        cublasSrotm(
+            queue.handle(),
+            n,
+            dx, incdx,
+            dy, incdy,
+            param));
+}
+
+//------------------------------------------------------------------------------
+void rotm(
+    device_blas_int n,
+    double* dx, device_blas_int incdx,
+    double* dy, device_blas_int incdy,
+    const double* param,
+    blas::Queue& queue )
+{
+    blas_dev_call(
+        cublasDrotm(
+            queue.handle(),
+            n,
+            dx, incdx,
+            dy, incdy,
+            param));
+}
+
+//------------------------------------------------------------------------------
+// rotmg
+//------------------------------------------------------------------------------
+void rotmg(
+    float* d1,
+    float* d2,
+    float* x1,
+    float* y1,
+    float* param,
+    blas::Queue& queue )
+{
+    blas_dev_call(
+        cublasSrotmg(
+            queue.handle(),
+            d1,
+            d2,
+            x1,
+            y1,
+            param));
+}
+
+//------------------------------------------------------------------------------
+void rotmg(
+    double* d1,
+    double* d2,
+    double* x1,
+    double* y1,
+    double* param,
+    blas::Queue& queue )
+{
+    blas_dev_call(
+        cublasDrotmg(
+            queue.handle(),
+            d1,
+            d2,
+            x1,
+            y1,
+            param));
+}
+
 //==============================================================================
 // Level 2 BLAS - Device Interfaces
 
