@@ -64,6 +64,68 @@ oneapi::mkl::side side2onemkl(blas::Side side)
 //==============================================================================
 // Level 1 BLAS - Device Interfaces
 
+// -----------------------------------------------------------------------------
+// asum
+//------------------------------------------------------------------------------
+void asum(
+    device_blas_int n,
+    float const* dx, device_blas_int incdx,
+    float* result,
+    blas::Queue& queue )
+{
+    blas_dev_call(
+        oneapi::mkl::blas::asum(
+            queue.stream(),
+            n,
+            dx, incdx,
+            result));
+}
+
+//------------------------------------------------------------------------------
+void asum(
+    device_blas_int n,
+    double const* dx, device_blas_int incdx,
+    double* result,
+    blas::Queue& queue )
+{
+    blas_dev_call(
+        oneapi::mkl::blas::asum(
+            queue.stream(),
+            n,
+            dx, incdx,
+            result));
+}
+
+//------------------------------------------------------------------------------
+void asum(
+    device_blas_int n,
+    std::complex<float> const* dx, device_blas_int incdx,
+    float* result,
+    blas::Queue& queue )
+{
+    blas_dev_call(
+        oneapi::mkl::blas::asum(
+            queue.stream(),
+            n,
+            dx, incdx,
+            result));
+}
+
+//------------------------------------------------------------------------------
+void asum(
+    device_blas_int n,
+    std::complex<double> const* dx, device_blas_int incdx,
+    double* result,
+    blas::Queue& queue )
+{
+    blas_dev_call(
+        oneapi::mkl::blas::asum(
+            queue.stream(),
+            n,
+            dx, incdx,
+            result));
+}
+
 //------------------------------------------------------------------------------
 // axpy
 //------------------------------------------------------------------------------
@@ -238,6 +300,116 @@ void dotu(
             result));
 }
 
+//------------------------------------------------------------------------------
+// iamax
+//------------------------------------------------------------------------------
+void iamax(
+    int64_t n,
+    float const* dx, int64_t incdx,
+    int64_t* result,
+    blas::Queue& queue )
+{
+    // Return -1 for non-positive n or incx. MKL routine would return 0.
+    if (n < 1 || incdx < 1) {
+        if (is_devptr( result, queue )) {
+            int64_t tmp = -1;
+            device_memcpy( result, &tmp, 1, queue );
+            queue.sync();
+        }
+        else {
+            *result = -1;
+        }
+        return;
+    }
+    blas_dev_call(
+        oneapi::mkl::blas::iamax(
+            queue.stream(),
+            n,
+            dx, incdx,
+            result));
+}
+
+//------------------------------------------------------------------------------
+void iamax(
+    int64_t n,
+    double const* dx, int64_t incdx,
+    int64_t* result,
+    blas::Queue& queue )
+{
+    // Return -1 for non-positive n or incx. MKL routine would return 0.
+    if (n < 1 || incdx < 1) {
+        if (is_devptr( result, queue )) {
+            int64_t tmp = -1;
+            device_memcpy( result, &tmp, 1, queue );
+            queue.sync();
+        }
+        else {
+            *result = -1;
+        }
+        return;
+    }
+    blas_dev_call(
+        oneapi::mkl::blas::iamax(
+            queue.stream(),
+            n,
+            dx, incdx,
+            result));
+}
+
+//------------------------------------------------------------------------------
+void iamax(
+    int64_t n,
+    std::complex<float> const* dx, int64_t incdx,
+    int64_t* result,
+    blas::Queue& queue )
+{
+    // Return -1 for non-positive n or incx. MKL routine would return 0.
+    if (n < 1 || incdx < 1) {
+        if (is_devptr( result, queue )) {
+            int64_t tmp = -1;
+            device_memcpy( result, &tmp, 1, queue );
+            queue.sync();
+        }
+        else {
+            *result = -1;
+        }
+        return;
+    }
+    blas_dev_call(
+        oneapi::mkl::blas::iamax(
+            queue.stream(),
+            n,
+            dx, incdx,
+            result));
+}
+
+//------------------------------------------------------------------------------
+void iamax(
+    int64_t n,
+    std::complex<double> const* dx, int64_t incdx,
+    int64_t* result,
+    blas::Queue& queue )
+{
+    // Return -1 for non-positive n or incx. MKL routine would return 0.
+    if (n < 1 || incdx < 1) {
+        if (is_devptr( result, queue )) {
+            int64_t tmp = -1;
+            device_memcpy( result, &tmp, 1, queue );
+            queue.sync();
+        }
+        else {
+            *result = -1;
+        }
+        return;
+    }
+    blas_dev_call(
+        oneapi::mkl::blas::iamax(
+            queue.stream(),
+            n,
+            dx, incdx,
+            result));
+}
+
 // -----------------------------------------------------------------------------
 // nrm2
 //------------------------------------------------------------------------------
@@ -486,6 +658,262 @@ void copy(
             dy, incdy) );
 }
 
+//------------------------------------------------------------------------------
+// rot
+//------------------------------------------------------------------------------
+void rot(
+    device_blas_int n,
+    float* dx, device_blas_int incdx,
+    float* dy, device_blas_int incdy,
+    const float c,
+    const float s,
+    blas::Queue& queue )
+{
+    blas_dev_call(
+        oneapi::mkl::blas::rot(
+            queue.stream(),
+            n,
+            dx, incdx,
+            dy, incdy,
+            c, s));
+}
+
+//------------------------------------------------------------------------------
+void rot(
+    device_blas_int n,
+    double* dx, device_blas_int incdx,
+    double* dy, device_blas_int incdy,
+    const double c,
+    const double s,
+    blas::Queue& queue )
+{
+    blas_dev_call(
+        oneapi::mkl::blas::rot(
+            queue.stream(),
+            n,
+            dx, incdx,
+            dy, incdy,
+            c, s));
+}
+
+//------------------------------------------------------------------------------
+void rot(
+    device_blas_int n,
+    std::complex<float>* dx, device_blas_int incdx,
+    std::complex<float>* dy, device_blas_int incdy,
+    const float c,
+    const float s,
+    blas::Queue& queue )
+{
+    blas_dev_call(
+        oneapi::mkl::blas::rot(
+            queue.stream(),
+            n,
+            dx, incdx,
+            dy, incdy,
+            c, s));
+}
+
+//------------------------------------------------------------------------------
+void rot(
+    device_blas_int n,
+    std::complex<double>* dx, device_blas_int incdx,
+    std::complex<double>* dy, device_blas_int incdy,
+    const double c,
+    const double s,
+    blas::Queue& queue )
+{
+    blas_dev_call(
+        oneapi::mkl::blas::rot(
+            queue.stream(),
+            n,
+            dx, incdx,
+            dy, incdy,
+            c, s));
+}
+
+//------------------------------------------------------------------------------
+void rot(
+    device_blas_int n,
+    std::complex<float>* dx, device_blas_int incdx,
+    std::complex<float>* dy, device_blas_int incdy,
+    const float c,
+    const std::complex<float> s,
+    blas::Queue& queue )
+{
+    blas_dev_call(
+        oneapi::mkl::blas::rot(
+            queue.stream(),
+            n,
+            dx, incdx,
+            dy, incdy,
+            c, s));
+}
+
+//------------------------------------------------------------------------------
+void rot(
+    device_blas_int n,
+    std::complex<double>* dx, device_blas_int incdx,
+    std::complex<double>* dy, device_blas_int incdy,
+    const double c,
+    const std::complex<double> s,
+    blas::Queue& queue )
+{
+    blas_dev_call(
+        oneapi::mkl::blas::rot(
+            queue.stream(),
+            n,
+            dx, incdx,
+            dy, incdy,
+            c, s));
+}
+
+//------------------------------------------------------------------------------
+// rotg
+//------------------------------------------------------------------------------
+void rotg(
+    float* da,
+    float* db,
+    float* dc,
+    float* ds,
+    blas::Queue& queue )
+{
+    blas_dev_call(
+        oneapi::mkl::blas::rotg(
+            queue.stream(),
+            da,
+            db,
+            dc,
+            ds));
+}
+
+//------------------------------------------------------------------------------
+void rotg(
+    double* da,
+    double* db,
+    double* dc,
+    double* ds,
+    blas::Queue& queue )
+{
+    blas_dev_call(
+        oneapi::mkl::blas::rotg(
+            queue.stream(),
+            da,
+            db,
+            dc,
+            ds));
+}
+
+//------------------------------------------------------------------------------
+void rotg(
+    std::complex<float>* da,
+    std::complex<float>* db,
+    float* dc,
+    std::complex<float>* ds,
+    blas::Queue& queue )
+{
+    blas_dev_call(
+        oneapi::mkl::blas::rotg(
+            queue.stream(),
+            da,
+            db,
+            dc,
+            ds));
+}
+
+//------------------------------------------------------------------------------
+void rotg(
+    std::complex<double>* da,
+    std::complex<double>* db,
+    double* dc,
+    std::complex<double>* ds,
+    blas::Queue& queue )
+{
+    blas_dev_call(
+        oneapi::mkl::blas::rotg(
+            queue.stream(),
+            da,
+            db,
+            dc,
+            ds));
+}
+
+//------------------------------------------------------------------------------
+// rotm
+//------------------------------------------------------------------------------
+void rotm(
+    device_blas_int n,
+    float* dx, device_blas_int incdx,
+    float* dy, device_blas_int incdy,
+    const float* param,
+    blas::Queue& queue )
+{
+    blas_dev_call(
+        oneapi::mkl::blas::rotm(
+            queue.stream(),
+            n,
+            dx, incdx,
+            dy, incdy,
+            param));
+}
+
+//------------------------------------------------------------------------------
+void rotm(
+    device_blas_int n,
+    double* dx, device_blas_int incdx,
+    double* dy, device_blas_int incdy,
+    const double* param,
+    blas::Queue& queue )
+{
+    blas_dev_call(
+        oneapi::mkl::blas::rotm(
+            queue.stream(),
+            n,
+            dx, incdx,
+            dy, incdy,
+            param));
+}
+
+//------------------------------------------------------------------------------
+// rotmg
+//------------------------------------------------------------------------------
+void rotmg(
+    float* d1,
+    float* d2,
+    float* x1,
+    float* y1,
+    float* param,
+    blas::Queue& queue )
+{
+    blas_dev_call(
+        oneapi::mkl::blas::rotmg(
+            queue.stream(),
+            d1,
+            d2,
+            x1,
+            y1,
+            param));
+}
+
+//------------------------------------------------------------------------------
+void rotmg(
+    double* d1,
+    double* d2,
+    double* x1,
+    double* y1,
+    double* param,
+    blas::Queue& queue )
+{
+    blas_dev_call(
+        oneapi::mkl::blas::rotmg(
+            queue.stream(),
+            d1,
+            d2,
+            x1,
+            y1,
+            param));
+}
+
 //==============================================================================
 // Level 2 BLAS - Device Interfaces
 
