@@ -91,7 +91,7 @@ std::vector< testsweeper::routines_t > routines = {
     { "axpy",   test_axpy,   Section::blas1   },
     { "copy",   test_copy,   Section::blas1   },
     { "dot",    test_dot,    Section::blas1   },
-    { "dotu",   test_dotu,   Section::blas1   },
+    { "dotu",   test_dot,    Section::blas1   },
     { "iamax",  test_iamax,  Section::blas1   },
     { "nrm2",   test_nrm2,   Section::blas1   },
     { "rot",    test_rot,    Section::blas1   },
@@ -105,7 +105,7 @@ std::vector< testsweeper::routines_t > routines = {
     // Level 2 BLAS
     { "gemv",   test_gemv,   Section::blas2   },
     { "ger",    test_ger,    Section::blas2   },
-    { "geru",   test_geru,   Section::blas2   },
+    { "geru",   test_ger,    Section::blas2   },
     { "",       nullptr,     Section::newline },
 
     { "hemv",   test_hemv,   Section::blas2   },
@@ -158,10 +158,16 @@ std::vector< testsweeper::routines_t > routines = {
     { "",              nullptr,          Section::newline },
 
     // Device Level 1 BLAS
+    { "dev-asum",         test_asum_device,         Section::device_blas1   },
     { "dev-axpy",         test_axpy_device,         Section::device_blas1   },
     { "dev-dot",          test_dot_device,          Section::device_blas1   },
-    { "dev-dotu",         test_dotu_device,         Section::device_blas1   },
+    { "dev-dotu",         test_dot_device,          Section::device_blas1   },
+    { "dev-iamax",        test_iamax_device,        Section::device_blas1   },
     { "dev-nrm2",         test_nrm2_device,         Section::device_blas1   },
+    { "dev-rot",          test_rot_device,          Section::device_blas1   },
+    { "dev-rotg",         test_rotg_device,         Section::device_blas1   },
+    { "dev-rotm",         test_rotm_device,         Section::device_blas1   },
+    { "dev-rotmg",        test_rotmg_device,        Section::device_blas1   },
     { "dev-scal",         test_scal_device,         Section::device_blas1   },
     { "dev-swap",         test_swap_device,         Section::device_blas1   },
     { "dev-copy",         test_copy_device,         Section::device_blas1   },
@@ -238,6 +244,7 @@ Params::Params():
     papi      ( "papi",       0, PT_Value, 'n', "ny", "run papi instrumentation" ),
 
     //          name,         w, p, type, default,  min,  max, help
+    tol       ( "tol",        0, 0, PT_Value,  20,    1, 1000, "tolerance (e.g., error < tol*epsilon to pass)" ),
     repeat    ( "repeat",     0,    PT_Value,   1,    1, 1000, "times to repeat each test" ),
     verbose   ( "verbose",    0,    PT_Value,   0,    0,   10, "verbose level" ),
     cache     ( "cache",      0,    PT_Value,  20,    1, 1024, "total cache size, in MiB" ),
@@ -459,6 +466,7 @@ int main( int argc, char** argv )
 
         // run tests
         int repeat = params.repeat();
+        std::vector<double> times( repeat ), gflops( repeat );
         testsweeper::DataType last = params.datatype();
         params.header();
         do {
@@ -476,6 +484,10 @@ int main( int argc, char** argv )
                     params.okay() = false;
                 }
 
+                // Collect stats.
+                times [ iter ] = params.time();
+                gflops[ iter ] = params.gflops();
+
                 params.print();
                 fflush( stdout );
 
@@ -493,6 +505,8 @@ int main( int argc, char** argv )
                 params.reset_output();
             }
             if (repeat > 1) {
+                testsweeper::print_stats( params.time,   times  );
+                testsweeper::print_stats( params.gflops, gflops );
                 printf( "\n" );
             }
         } while(params.next());
