@@ -16,8 +16,7 @@ void test_device_batch_gemm_work( Params& params, bool run )
 {
     using namespace testsweeper;
     using namespace blas::batch;
-    using blas::Op;
-    using blas::Layout;
+    using blas::Op, blas::Layout, blas::max;
     using scalar_t = blas::scalar_type< TA, TB, TC >;
     using real_t   = blas::real_type< scalar_t >;
 
@@ -61,9 +60,9 @@ void test_device_batch_gemm_work( Params& params, bool run )
         std::swap( Cm, Cn );
     }
 
-    int64_t lda_ = roundup( Am, align );
-    int64_t ldb_ = roundup( Bm, align );
-    int64_t ldc_ = roundup( Cm, align );
+    int64_t lda_ = max( roundup( Am, align ), 1 );
+    int64_t ldb_ = max( roundup( Bm, align ), 1 );
+    int64_t ldc_ = max( roundup( Cm, align ), 1 );
     size_t size_A = size_t(lda_)*An;
     size_t size_B = size_t(ldb_)*Bn;
     size_t size_C = size_t(ldc_)*Cn;
