@@ -15,8 +15,7 @@ template <typename TA, typename TB, typename TC>
 void test_batch_symm_device_work( Params& params, bool run )
 {
     using namespace testsweeper;
-    using blas::Side;
-    using blas::Layout;
+    using blas::Side, blas::Layout, blas::max;
     using scalar_t = blas::scalar_type< TA, TB, TC >;
     using real_t   = blas::real_type< scalar_t >;
 
@@ -52,9 +51,9 @@ void test_batch_symm_device_work( Params& params, bool run )
     int64_t Cn = n_;
     if (layout == Layout::RowMajor)
         std::swap( Cm, Cn );
-    int64_t lda_ = roundup( An, align );
-    int64_t ldb_ = roundup( Cm, align );
-    int64_t ldc_ = roundup( Cm, align );
+    int64_t lda_ = max( roundup( An, align ), 1 );
+    int64_t ldb_ = max( roundup( Cm, align ), 1 );
+    int64_t ldc_ = max( roundup( Cm, align ), 1 );
     size_t size_A = size_t(lda_)*An;
     size_t size_B = size_t(ldb_)*Cn;
     size_t size_C = size_t(ldc_)*Cn;
