@@ -15,8 +15,7 @@ template <typename TA, typename TB>
 void test_batch_trmm_work_device( Params& params, bool run )
 {
     using namespace testsweeper;
-    using blas::Side;
-    using blas::Layout;
+    using blas::Side, blas::Layout, blas::max;
     using scalar_t = blas::scalar_type< TA, TB >;
     using real_t   = blas::real_type< scalar_t >;
 
@@ -54,8 +53,8 @@ void test_batch_trmm_work_device( Params& params, bool run )
     int64_t Bn = n_;
     if (layout == Layout::RowMajor)
         std::swap( Bm, Bn );
-    int64_t lda_ = roundup( Am, align );
-    int64_t ldb_ = roundup( Bm, align );
+    int64_t lda_ = max( roundup( Am, align ), 1 );
+    int64_t ldb_ = max( roundup( Bm, align ), 1 );
     size_t size_A = size_t(lda_)*Am;
     size_t size_B = size_t(ldb_)*Bn;
     TA* A    = new TA[ batch * size_A ];
