@@ -15,23 +15,21 @@ template <typename TA, typename TC>
 void test_herk_device_work( Params& params, bool run )
 {
     using namespace testsweeper;
-    using blas::Uplo;
-    using blas::Op;
-    using blas::Layout;
+    using blas::Uplo, blas::Op, blas::Layout, blas::max;
     using scalar_t = blas::scalar_type< TA, TC >;
     using real_t   = blas::real_type< scalar_t >;
 
     // get & mark input values
     blas::Layout layout = params.layout();
-    blas::Op trans      = params.trans();
-    blas::Uplo uplo     = params.uplo();
-    real_t alpha        = params.alpha.get<real_t>();  // note: real
-    real_t beta         = params.beta.get<real_t>();   // note: real
-    int64_t n           = params.dim.n();
-    int64_t k           = params.dim.k();
-    int64_t device      = params.device();
-    int64_t align       = params.align();
-    int64_t verbose     = params.verbose();
+    blas::Op trans  = params.trans();
+    blas::Uplo uplo = params.uplo();
+    real_t alpha    = params.alpha.get<real_t>();  // note: real
+    real_t beta     = params.beta.get<real_t>();   // note: real
+    int64_t n       = params.dim.n();
+    int64_t k       = params.dim.k();
+    int64_t device  = params.device();
+    int64_t align   = params.align();
+    int64_t verbose = params.verbose();
 
     // mark non-standard output values
     params.gflops();
@@ -51,8 +49,8 @@ void test_herk_device_work( Params& params, bool run )
     int64_t An = (trans == Op::NoTrans ? k : n);
     if (layout == Layout::RowMajor)
         std::swap( Am, An );
-    int64_t lda = roundup( Am, align );
-    int64_t ldc = roundup(  n, align );
+    int64_t lda = max( roundup( Am, align ), 1 );
+    int64_t ldc = max( roundup(  n, align ), 1 );
     size_t size_A = size_t(lda)*An;
     size_t size_C = size_t(ldc)*n;
     TA* A    = new TA[ size_A ];
@@ -73,8 +71,8 @@ void test_herk_device_work( Params& params, bool run )
     lapack_larnv( idist, iseed, size_C, C );
     lapack_lacpy( "g", n, n, C, ldc, Cref, ldc );
 
-    blas::device_copy_matrix(Am, An, A, lda, dA, lda, queue);
-    blas::device_copy_matrix(n,  n,  C, ldc, dC, ldc, queue);
+    blas::device_copy_matrix( Am, An, A, lda, dA, lda, queue );
+    blas::device_copy_matrix( n,  n,  C, ldc, dC, ldc, queue );
     queue.sync();
 
     // norms for error check
@@ -99,6 +97,11 @@ void test_herk_device_work( Params& params, bool run )
 
     assert_throw( blas::herk( layout,    uplo,    trans,  n,  k, alpha, dA, lda, beta, dC, n-1, queue ), blas::Error );
 
+    if (blas::is_complex_v<scalar_t>) {
+        // complex herk doesn't allow Trans, only ConjTrans
+        assert_throw( blas::herk( layout, uplo, Op::Trans, n, k, alpha, dA, lda, beta, dC, ldc, queue ), blas::Error );
+    }
+
     if (verbose >= 1) {
         printf( "\n"
                 "uplo %c, trans %c\n"
