@@ -190,12 +190,12 @@ void test_is_complex()
 {
     printf( "%s\n", __func__ );
 
-    require( ! blas::is_complex< int >::value );
-    require( ! blas::is_complex< int64_t >::value );
-    require( ! blas::is_complex< float >::value );
-    require( ! blas::is_complex< double >::value );
-    require( blas::is_complex< std::complex<float> >::value );
-    require( blas::is_complex< std::complex<double> >::value );
+    require( ! blas::is_complex_v< int > );
+    require( ! blas::is_complex_v< int64_t > );
+    require( ! blas::is_complex_v< float > );
+    require( ! blas::is_complex_v< double > );
+    require( blas::is_complex_v< std::complex<float> > );
+    require( blas::is_complex_v< std::complex<double> > );
 }
 
 // -----------------------------------------------------------------------------
@@ -278,30 +278,30 @@ void test_real_type()
     printf( "%s\n", __func__ );
 
     // Extra parens needed to avoid confusing preprocessor: require( (...) );
-    require( (std::is_same< blas::real_type< float  >, float  >::value) );
-    require( (std::is_same< blas::real_type< double >, double >::value) );
-    require( (std::is_same< blas::real_type< std::complex<float>  >, float  >::value) );
-    require( (std::is_same< blas::real_type< std::complex<double> >, double >::value) );
+    require( (std::is_same_v< blas::real_type< float  >, float  >) );
+    require( (std::is_same_v< blas::real_type< double >, double >) );
+    require( (std::is_same_v< blas::real_type< std::complex<float>  >, float  >) );
+    require( (std::is_same_v< blas::real_type< std::complex<double> >, double >) );
 
     // pairs
-    require( (std::is_same< blas::real_type< float,  float  >, float  >::value) );
-    require( (std::is_same< blas::real_type< float,  double >, double >::value) );
-    require( (std::is_same< blas::real_type< double, double >, double >::value) );
-    require( (std::is_same< blas::real_type< float,  std::complex<float>  >, float  >::value) );
-    require( (std::is_same< blas::real_type< double, std::complex<float>  >, double >::value) );
-    require( (std::is_same< blas::real_type< float,  std::complex<double> >, double >::value) );
-    require( (std::is_same< blas::real_type< double, std::complex<double> >, double >::value) );
-    require( (std::is_same< blas::real_type< std::complex<float>,  float  >, float  >::value) );
-    require( (std::is_same< blas::real_type< std::complex<double>, float  >, double >::value) );
-    require( (std::is_same< blas::real_type< std::complex<double>, double >, double >::value) );
-    require( (std::is_same< blas::real_type< std::complex<float>, std::complex<double> >, double >::value) );
+    require( (std::is_same_v< blas::real_type< float,  float  >, float  >) );
+    require( (std::is_same_v< blas::real_type< float,  double >, double >) );
+    require( (std::is_same_v< blas::real_type< double, double >, double >) );
+    require( (std::is_same_v< blas::real_type< float,  std::complex<float>  >, float  >) );
+    require( (std::is_same_v< blas::real_type< double, std::complex<float>  >, double >) );
+    require( (std::is_same_v< blas::real_type< float,  std::complex<double> >, double >) );
+    require( (std::is_same_v< blas::real_type< double, std::complex<double> >, double >) );
+    require( (std::is_same_v< blas::real_type< std::complex<float>,  float  >, float  >) );
+    require( (std::is_same_v< blas::real_type< std::complex<double>, float  >, double >) );
+    require( (std::is_same_v< blas::real_type< std::complex<double>, double >, double >) );
+    require( (std::is_same_v< blas::real_type< std::complex<float>, std::complex<double> >, double >) );
 
     // triples
-    require( (std::is_same< blas::real_type< float, float,  float >, float  >::value) );
-    require( (std::is_same< blas::real_type< float, double, float >, double >::value) );
-    require( (std::is_same< blas::real_type< float, float,  std::complex<float>  >, float  >::value) );
-    require( (std::is_same< blas::real_type< float, double, std::complex<double> >, double >::value) );
-    require( (std::is_same< blas::real_type< float, double, std::complex<float>  >, double >::value) );
+    require( (std::is_same_v< blas::real_type< float, float,  float >, float  >) );
+    require( (std::is_same_v< blas::real_type< float, double, float >, double >) );
+    require( (std::is_same_v< blas::real_type< float, float,  std::complex<float>  >, float  >) );
+    require( (std::is_same_v< blas::real_type< float, double, std::complex<double> >, double >) );
+    require( (std::is_same_v< blas::real_type< float, double, std::complex<float>  >, double >) );
 }
 
 // -----------------------------------------------------------------------------
@@ -310,30 +310,30 @@ void test_complex_type()
     printf( "%s\n", __func__ );
 
     // Extra parens needed to avoid confusing preprocessor: require( (...) );
-    require( (std::is_same< blas::complex_type< float  >, std::complex<float>  >::value) );
-    require( (std::is_same< blas::complex_type< double >, std::complex<double> >::value) );
-    require( (std::is_same< blas::complex_type< std::complex<float>  >, std::complex<float>  >::value) );
-    require( (std::is_same< blas::complex_type< std::complex<double> >, std::complex<double> >::value) );
+    require( (std::is_same_v< blas::complex_type< float  >, std::complex<float>  >) );
+    require( (std::is_same_v< blas::complex_type< double >, std::complex<double> >) );
+    require( (std::is_same_v< blas::complex_type< std::complex<float>  >, std::complex<float>  >) );
+    require( (std::is_same_v< blas::complex_type< std::complex<double> >, std::complex<double> >) );
 
     // pairs
-    require( (std::is_same< blas::complex_type< float,  float  >, std::complex<float>  >::value) );
-    require( (std::is_same< blas::complex_type< float,  double >, std::complex<double> >::value) );
-    require( (std::is_same< blas::complex_type< double, double >, std::complex<double> >::value) );
-    require( (std::is_same< blas::complex_type< float,  std::complex<float>  >, std::complex<float>  >::value) );
-    require( (std::is_same< blas::complex_type< double, std::complex<float>  >, std::complex<double> >::value) );
-    require( (std::is_same< blas::complex_type< float,  std::complex<double> >, std::complex<double> >::value) );
-    require( (std::is_same< blas::complex_type< double, std::complex<double> >, std::complex<double> >::value) );
-    require( (std::is_same< blas::complex_type< std::complex<float>,  float  >, std::complex<float>  >::value) );
-    require( (std::is_same< blas::complex_type< std::complex<double>, float  >, std::complex<double> >::value) );
-    require( (std::is_same< blas::complex_type< std::complex<double>, double >, std::complex<double> >::value) );
-    require( (std::is_same< blas::complex_type< std::complex<float>, std::complex<double> >, std::complex<double> >::value) );
+    require( (std::is_same_v< blas::complex_type< float,  float  >, std::complex<float>  >) );
+    require( (std::is_same_v< blas::complex_type< float,  double >, std::complex<double> >) );
+    require( (std::is_same_v< blas::complex_type< double, double >, std::complex<double> >) );
+    require( (std::is_same_v< blas::complex_type< float,  std::complex<float>  >, std::complex<float>  >) );
+    require( (std::is_same_v< blas::complex_type< double, std::complex<float>  >, std::complex<double> >) );
+    require( (std::is_same_v< blas::complex_type< float,  std::complex<double> >, std::complex<double> >) );
+    require( (std::is_same_v< blas::complex_type< double, std::complex<double> >, std::complex<double> >) );
+    require( (std::is_same_v< blas::complex_type< std::complex<float>,  float  >, std::complex<float>  >) );
+    require( (std::is_same_v< blas::complex_type< std::complex<double>, float  >, std::complex<double> >) );
+    require( (std::is_same_v< blas::complex_type< std::complex<double>, double >, std::complex<double> >) );
+    require( (std::is_same_v< blas::complex_type< std::complex<float>, std::complex<double> >, std::complex<double> >) );
 
     // triples
-    require( (std::is_same< blas::complex_type< float, float,  float >, std::complex<float>  >::value) );
-    require( (std::is_same< blas::complex_type< float, double, float >, std::complex<double> >::value) );
-    require( (std::is_same< blas::complex_type< float, float,  std::complex<float>  >, std::complex<float>  >::value) );
-    require( (std::is_same< blas::complex_type< float, double, std::complex<double> >, std::complex<double> >::value) );
-    require( (std::is_same< blas::complex_type< float, double, std::complex<float>  >, std::complex<double> >::value) );
+    require( (std::is_same_v< blas::complex_type< float, float,  float >, std::complex<float>  >) );
+    require( (std::is_same_v< blas::complex_type< float, double, float >, std::complex<double> >) );
+    require( (std::is_same_v< blas::complex_type< float, float,  std::complex<float>  >, std::complex<float>  >) );
+    require( (std::is_same_v< blas::complex_type< float, double, std::complex<double> >, std::complex<double> >) );
+    require( (std::is_same_v< blas::complex_type< float, double, std::complex<float>  >, std::complex<double> >) );
 }
 
 // -----------------------------------------------------------------------------
@@ -342,30 +342,30 @@ void test_scalar_type()
     printf( "%s\n", __func__ );
 
     // Extra parens needed to avoid confusing preprocessor: require( (...) );
-    require( (std::is_same< blas::scalar_type< float  >, float  >::value) );
-    require( (std::is_same< blas::scalar_type< double >, double >::value) );
-    require( (std::is_same< blas::scalar_type< std::complex<float>  >, std::complex<float>  >::value) );
-    require( (std::is_same< blas::scalar_type< std::complex<double> >, std::complex<double> >::value) );
+    require( (std::is_same_v< blas::scalar_type< float  >, float  >) );
+    require( (std::is_same_v< blas::scalar_type< double >, double >) );
+    require( (std::is_same_v< blas::scalar_type< std::complex<float>  >, std::complex<float>  >) );
+    require( (std::is_same_v< blas::scalar_type< std::complex<double> >, std::complex<double> >) );
 
     // pairs
-    require( (std::is_same< blas::scalar_type< float,  float  >, float  >::value) );
-    require( (std::is_same< blas::scalar_type< float,  double >, double >::value) );
-    require( (std::is_same< blas::scalar_type< double, double >, double >::value) );
-    require( (std::is_same< blas::scalar_type< float,  std::complex<float>  >, std::complex<float>  >::value) );
-    require( (std::is_same< blas::scalar_type< double, std::complex<float>  >, std::complex<double> >::value) );
-    require( (std::is_same< blas::scalar_type< float,  std::complex<double> >, std::complex<double> >::value) );
-    require( (std::is_same< blas::scalar_type< double, std::complex<double> >, std::complex<double> >::value) );
-    require( (std::is_same< blas::scalar_type< std::complex<float>,  float  >, std::complex<float>  >::value) );
-    require( (std::is_same< blas::scalar_type< std::complex<double>, float  >, std::complex<double> >::value) );
-    require( (std::is_same< blas::scalar_type< std::complex<double>, double >, std::complex<double> >::value) );
-    require( (std::is_same< blas::scalar_type< std::complex<float>, std::complex<double> >, std::complex<double> >::value) );
+    require( (std::is_same_v< blas::scalar_type< float,  float  >, float  >) );
+    require( (std::is_same_v< blas::scalar_type< float,  double >, double >) );
+    require( (std::is_same_v< blas::scalar_type< double, double >, double >) );
+    require( (std::is_same_v< blas::scalar_type< float,  std::complex<float>  >, std::complex<float>  >) );
+    require( (std::is_same_v< blas::scalar_type< double, std::complex<float>  >, std::complex<double> >) );
+    require( (std::is_same_v< blas::scalar_type< float,  std::complex<double> >, std::complex<double> >) );
+    require( (std::is_same_v< blas::scalar_type< double, std::complex<double> >, std::complex<double> >) );
+    require( (std::is_same_v< blas::scalar_type< std::complex<float>,  float  >, std::complex<float>  >) );
+    require( (std::is_same_v< blas::scalar_type< std::complex<double>, float  >, std::complex<double> >) );
+    require( (std::is_same_v< blas::scalar_type< std::complex<double>, double >, std::complex<double> >) );
+    require( (std::is_same_v< blas::scalar_type< std::complex<float>, std::complex<double> >, std::complex<double> >) );
 
     // triples
-    require( (std::is_same< blas::scalar_type< float, float,  float >, float  >::value) );
-    require( (std::is_same< blas::scalar_type< float, double, float >, double >::value) );
-    require( (std::is_same< blas::scalar_type< float, float,  std::complex<float>  >, std::complex<float>  >::value) );
-    require( (std::is_same< blas::scalar_type< float, double, std::complex<double> >, std::complex<double> >::value) );
-    require( (std::is_same< blas::scalar_type< float, double, std::complex<float>  >, std::complex<double> >::value) );
+    require( (std::is_same_v< blas::scalar_type< float, float,  float >, float  >) );
+    require( (std::is_same_v< blas::scalar_type< float, double, float >, double >) );
+    require( (std::is_same_v< blas::scalar_type< float, float,  std::complex<float>  >, std::complex<float>  >) );
+    require( (std::is_same_v< blas::scalar_type< float, double, std::complex<double> >, std::complex<double> >) );
+    require( (std::is_same_v< blas::scalar_type< float, double, std::complex<float>  >, std::complex<double> >) );
 }
 
 // -----------------------------------------------------------------------------
@@ -397,7 +397,7 @@ void test_device_routines()
 {
     printf( "%s\n", __func__ );
 
-    int repeat = 4;
+    const int repeat = 4;
     double t;
     int device_cnt;
 
@@ -871,6 +871,36 @@ void test_queue_fork()
     }
 }
 
+// -----------------------------------------------------------------------------
+void test_is_devptr()
+{
+    printf( "%s\n", __func__ );
+
+    int device_cnt = blas::get_device_count();
+    if (device_cnt == 0)
+        return;
+
+    int dev = 0;
+    int size = 1024;
+    float* devptr;
+    float* hostptr = new float[ size ];
+
+    blas::Queue queue( dev );
+
+    devptr = blas::device_malloc< float >( 1024, queue );
+    queue.sync();
+
+    require(blas::is_devptr( devptr, queue ) == 1);
+    require(blas::is_devptr( hostptr, queue ) == 0);
+
+    queue.sync();
+    blas::device_free( devptr, queue );
+    delete[] hostptr;
+
+    // queue is destroyed here.
+    printf( "    ~queue\n" );
+}
+
 // -----------------------------------------------------------------------------
 void test_util( Params& params, bool run )
 {
@@ -900,6 +930,7 @@ void test_util( Params& params, bool run )
         test_queue();
         test_queue_from_stream();
         test_queue_fork();
+        test_is_devptr();
         printf( "\n" );
     }
 
